
Welcome to Impact's documentation!
==================================
|build-status| |license| |pypi-version| 

|linux| |windows|

**Impact**: A Toolchain for Nonlinear Model Predictive Control Specification, Prototyping, and Deployment

=============================================================================================

Table of contents
=================

.. toctree::
  :caption: About
  :maxdepth: 1

  intro/install
  intro/license
  intro/citing
  intro/contributing
  intro/contact

.. toctree::
  :caption: Getting started
  :maxdepth: 1

  tutorial/getting_started

.. toctree::
  :caption: Generated artifacts
  :maxdepth: 1

  artifacts/artifacts

.. toctree::
  :caption: Examples
  :maxdepth: 1

  examples/index

.. toctree::
  :caption: API reference - Python
  :maxdepth: 2

  api_reference/classes



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |build-status| image:: https://gitlab.mech.kuleuven.be/meco-software/impact/badges/main/pipeline.svg
    :alt: Build status
    :target: https://gitlab.mech.kuleuven.be/meco-software/impact/commits/main

.. |license| image:: https://img.shields.io/badge/license-LGPL%20v3-success.svg
    :alt: License
    :target: intro/license.html

.. |pypi-version| image:: https://badge.fury.io/py/impact-meco.svg
    :alt: PyPi version
    :target: https://badge.fury.io/py/impact-meco

.. |linux| image:: https://img.shields.io/badge/Linux-FCC624?logo=linux&logoColor=black
    :alt: Linux

.. |windows| image:: https://img.shields.io/badge/Windows-0078D6?st&logo=windows&logoColor=white
    :alt: Windows